#
# spec file for package libcdirectory
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define lname	libcdirectory1
Name:           libcdirectory
Version:        20220105
Release:        3.1
Summary:        Library for Windows NT data types
License:        GFDL-1.3-or-later AND LGPL-3.0-or-later
Group:          Productivity/File utilities
URL:            https://github.com/libyal/libcdirectory
Source:         https://github.com/libyal/libcdirectory/releases/download/%version/%name-experimental-%version.tar.gz
Source2:        https://github.com/libyal/libcdirectory/releases/download/%version/%name-experimental-%version.tar.gz.asc
Source3:        %name.keyring
BuildRequires:  c_compiler
BuildRequires:  pkg-config
BuildRequires:  pkgconfig(libcerror) >= 20220101
BuildRequires:  pkgconfig(libclocale) >= 20210526
BuildRequires:  pkgconfig(libuna) >= 20210801
# Various notes: https://en.opensuse.org/libyal

%description
Library to provide Windows NT data type support for the libyal family of libraries.
libyal is typically used in digital forensic tools.

%package -n %{lname}
Summary:        Library for Windows NT data types
License:        LGPL-3.0-or-later
Group:          System/Libraries

%description -n %{lname}
Library to provide Windows NT data type support for the libyal family of libraries.
libyal is typically used in digital forensic tools.

%package devel
Summary:        Development files for libcdirectory
License:        GFDL-1.3-or-later AND LGPL-3.0-or-later
Group:          Development/Libraries/C and C++
Requires:       %{lname} = %{version}

%description devel
Library to provide Windows NT data type support for the libyal family of libraries.  libyal is typically used in digital forensic tools.

This subpackage contains libraries and header files for developing
applications that want to make use of libcdirectory.

%prep
%autosetup -p1

%build
echo "V_%version { global: *; };" >v.sym
%configure --disable-static --enable-wide-character-type LDFLAGS="-Wl,--version-script=$PWD/v.sym"
grep '  local' config.log && exit 1
%make_build

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print

%post   -n %{lname} -p /sbin/ldconfig
%postun -n %{lname} -p /sbin/ldconfig

%files -n %{lname}
%license COPYING*
%{_libdir}/libcdirectory.so.*

%files devel
%license COPYING*
%{_includedir}/libcdirectory.h
%{_includedir}/libcdirectory/
%{_libdir}/libcdirectory.so
%{_libdir}/pkgconfig/libcdirectory.pc
%{_mandir}/man3/libcdirectory.3*

%changelog
* Sun Dec  3 2023 Jan Engelhardt <jengelh@inai.de>
- Add signature and keyring
* Sat Nov 26 2022 Jan Engelhardt <jengelh@inai.de>
- Delete system-libs.patch (not needed - system libs are
  autodetected)
* Mon Aug 29 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 20220105
  * No changelog was provided
* Mon Aug  8 2022 Jan Engelhardt <jengelh@inai.de>
- Add forced symvers
* Thu May 13 2021 Jan Engelhardt <jengelh@inai.de>
- Update to snapshot 20210415 (63fab974)
  * No changelog was provided
- Add system-libs.patch
* Sun Dec 27 2020 Greg Freemyer <Greg.Freemyer@gmail.com>
- update to v0~20200702
  * code clean up
* Wed Feb 15 2017 Greg.Freemyer@gmail.com
- update to v0~20170104
  * worked on tests
  * bug fixes in WINAPI support
  * code clean up
  * worked on tests
  * removed USE_CRT_FUNCTIONS support
  * updated dependencies
* Mon Jan 12 2015 Greg.Freemyer@gmail.com
- initial package v0~20150101
